@@ -22,12 +22,12 @@ from . import internal
 def add_deploy_cmd(s):
     p = s.add_parser(
         'deploy', help='部署并启动服务。')
-    internal.add_arg_group_host(p)
+    internal.add_arg_host(p)
     internal.add_arg_force(p)
     p.set_defaults(func=deploy_cmd)
 
 
 def deploy_cmd(p):
-    hosts = internal.get_arg_group_host_from_conf(p)
-    internal.rsync(hosts, p.force)
-    return internal.docker_compose_cmd("up -d", hosts)
+    host = internal.get_arg_host_from_conf(p)
+    internal.sync(host, p.force)
+    return internal.docker_compose_cmd("up -d", host)
