@@ -61,6 +61,15 @@ class ArgsError(DropsErr):
     def __str__(self):
         return 'Args error: %s.' % (' '.join(self.args))
 
+class UnsupportedSyncObject(DropsErr):
+    def __str__(self) -> str:
+        return 'Unsupported sync object: %s.' % (' '.join(self.args))
+
+
+class UnsupportedBackupObject(DropsErr):
+    def __str__(self) -> str:
+        return 'Unsupported backup object: %s.' % (' '.join(self.args))
+
 
 class CmdNotExist(DropsErr):
     def __str__(self) -> str:
@@ -76,15 +85,9 @@ class ConfigurationFileFormatError(DropsErr):
     def __str__(self):
         return 'Configuration file format error.'
 
-
-class HostGroupNotExist(DropsErr):
+class HostDoesNotExist(DropsErr):
     def __str__(self):
-        return 'Host group "%s" does not exit.' % self.args[0]
-
-
-class HostNotInGroup(DropsErr):
-    def __str__(self):
-        return 'Host "%s" is not in group "%s".' % (self.args[1], self.args[0])
+        return 'Host %s does not exist' % self.args[0]
 
 
 class CmdCannotContain(DropsErr):
