@@ -22,14 +22,14 @@ from . import internal
 def add_kill_cmd(s):
     p = s.add_parser(
         'kill', help='杀掉容器。')
-    internal.add_arg_group_host(p)
+    internal.add_arg_host(p)
     internal.add_arg_container(p)
     p.set_defaults(func=kill_cmd)
 
 
 def kill_cmd(p):
-    hosts = internal.get_arg_group_host_from_conf(p)
+    host = internal.get_arg_host_from_conf(p)
     b = 'kill'
     if p.container:
         b += ' ' + ' '.join(p.container)
-    return internal.docker_compose_cmd(b, hosts)
+    return internal.docker_compose_cmd(b, host)
